macro_rules! always {
($cond:expr) => { ... };
($cond:expr, $fmt:literal $($arg:tt)*) => { ... };
}Expand description
Asserts that the condition is always true and returns its actual value.
If the condition is true does nothing and evaluates to true.
If the condition is false:
- panics if
forcefeature ordebug_assertionsare enabled, - logs an error if the
tracingfeature is enabled, - evaluates to false.
Accepts format! style arguments.